@@ -4,7 +4,7 @@
 #include "AggDeviceCapture.h"
 
 // [[export]]
-SEXP agg_capture_c(SEXP name, SEXP width, SEXP height, SEXP pointsize, SEXP bg, SEXP res) {
+SEXP agg_capture_c(SEXP name, SEXP width, SEXP height, SEXP pointsize, SEXP bg, SEXP res, SEXP scaling) {
   int bgCol = RGBpar(bg, 0);
   
   BEGIN_CPP
@@ -14,7 +14,8 @@ SEXP agg_capture_c(SEXP name, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
     INTEGER(height)[0], 
     REAL(pointsize)[0], 
     bgCol,
-    REAL(res)[0]
+    REAL(res)[0],
+    REAL(scaling)[0]
   );
   makeDevice<AggDeviceCaptureAlpha>(device, CHAR(STRING_ELT(name, 0)));
   END_CPP
