@@ -5,7 +5,8 @@
 
 // [[export]]
 SEXP agg_tiff_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
-                SEXP res, SEXP bit, SEXP compression, SEXP encoding) {
+                SEXP res, SEXP scaling, SEXP bit, SEXP compression, 
+                SEXP encoding) {
   bool bit8 = INTEGER(bit)[0] == 8;
   int bgCol = RGBpar(bg, 0);
   
@@ -19,6 +20,7 @@ SEXP agg_tiff_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
+        REAL(scaling)[0],
         INTEGER(compression)[0],
         INTEGER(encoding)[0]
       );
@@ -31,6 +33,7 @@ SEXP agg_tiff_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
+        REAL(scaling)[0],
         INTEGER(compression)[0],
         INTEGER(encoding)[0]
       );
@@ -45,6 +48,7 @@ SEXP agg_tiff_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
+        REAL(scaling)[0],
         INTEGER(compression)[0],
         INTEGER(encoding)[0]
       );
@@ -57,6 +61,7 @@ SEXP agg_tiff_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
         REAL(pointsize)[0], 
         bgCol,
         REAL(res)[0],
+        REAL(scaling)[0],
         INTEGER(compression)[0],
         INTEGER(encoding)[0]
       );
